ProSHADE: File List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

File List
Here is a list of all documented files with brief descriptions:
[detail level 123]

▼ src |
▼ bin |
bin.cpp | This code is the main function for the executable
▼ proshade |
ProSHADE.cpp | This is the main source file providing the main access class and its functions
ProSHADE.hpp | This is the main header file providing the main access class and its functions
ProSHADE_data.cpp | This is the source file containing internal data representation and manipulation structures and functions
ProSHADE_data.hpp | This is the header file containing internal data representation and manipulation structures and functions
ProSHADE_distances.cpp | This is the source file containing functions required for computation of shape distances
ProSHADE_distances.hpp | This is the header file containing declarations of functions required for computation of shape distances
ProSHADE_exceptions.hpp | This header file contains the ProSHADE_exception class, which is used to report errors occuring during run-time
ProSHADE_io.cpp | This source file contains the functions required for specifc data format manipulations
ProSHADE_io.hpp | This header file declares all the functions required for low level file format access
ProSHADE_mapManip.cpp | This source file contains the functions required for internal map manipulation for various purposes
ProSHADE_mapManip.hpp | This header file declares the ProSHADE_internal_mapManip namespace, which groups functions for internal map manipulation
ProSHADE_maths.cpp | This source file contains all the mathematical functions not simply available from elsewhere or modified to work with ProSHADE specific data formats
ProSHADE_maths.hpp | This header file declares all the functions required for computing various information from the ProSHADE data
ProSHADE_messages.cpp | This source file contains all user message functions
ProSHADE_messages.hpp | This header file contains all message function declarations
ProSHADE_misc.cpp | This source file contains all miscellaneous functions
ProSHADE_misc.hpp | This header file declares all miscellaneous functions
ProSHADE_overlay.cpp | This source file contains the functions required for structure overlay computations
ProSHADE_overlay.hpp | This header file declares the functions required for the structure overlay computation
ProSHADE_peakSearch.cpp | This source file declares functions required for peak searching and peak position optimisation
ProSHADE_peakSearch.hpp | This header file declares functions required for 3D map peak searching
ProSHADE_precomputedValues.hpp |
ProSHADE_settings.hpp | This header file declares the ProSHADE_settings class, which is the main information carrying object in ProSHADE
ProSHADE_spheres.cpp | This source file contains function related to the ProSHADE_sphere class, which generally serve to prepare a shell for SH decomposition
ProSHADE_spheres.hpp | This header file contains the declarations for the ProSHADE_sphere class
ProSHADE_sphericalHarmonics.cpp | This source file contains the function required to compute the spherical harmonics decompostion in ProSHADE
ProSHADE_sphericalHarmonics.hpp | This header file declares the functions required to compute the spherical harmonics decomposition for a particular sphere
ProSHADE_symmetry.cpp | This source file contains all the functions required to detect symmetry axes and types from the inverse SOFT map
ProSHADE_symmetry.hpp | This header file declares all the functions required for symmetry detection and construction
ProSHADE_tasks.cpp | This source file contains the task functions, which drive the computation of a specific task
ProSHADE_tasks.hpp | This header declares all the taks functions
ProSHADE_typedefs.hpp | This header contains the type definitions for ProSHADE
ProSHADE_version.hpp |
ProSHADE_wignerMatrices.cpp | This source file contains all the functions required to compute the Wigner D matrices
ProSHADE_wignerMatrices.hpp | This header declares the functions required to compute the Wigner D matrices
▼ python |
pyProSHADE.cpp | This file contains the PyBind11 bindings for the ProSHADE_settings class
pyProSHADE_bindings.cpp | This file contains and combines the PyBind11 bindings for the ProSHADE python module
pyProSHADE_data.cpp |
pyProSHADE_distances.cpp |